@@ -24,7 +24,6 @@
 #include "smbd/globals.h"
 #include "libcli/security/security.h"
 #include "lib/util/bitmap.h"
-#include "memcache.h"
 
 /*
    This module implements directory related functions for Samba.
@@ -35,11 +34,6 @@
 #define START_OF_DIRECTORY_OFFSET ((long)0)
 #define DOT_DOT_DIRECTORY_OFFSET ((long)0x80000000)
 
-/* "Special" directory offsets in 32-bit wire format. */
-#define WIRE_END_OF_DIRECTORY_OFFSET ((uint32_t)0xFFFFFFFF)
-#define WIRE_START_OF_DIRECTORY_OFFSET ((uint32_t)0)
-#define WIRE_DOT_DOT_DIRECTORY_OFFSET ((uint32_t)0x80000000)
-
 /* Make directory handle internals available. */
 
 struct name_cache_entry {
@@ -73,8 +67,6 @@ struct dptr_struct {
 	bool has_wild; /* Set to true if the wcard entry has MS wildcard characters in it. */
 	bool did_stat; /* Optimisation for non-wcard searches. */
 	bool priv;     /* Directory handle opened with privilege. */
-	uint32_t counter;
-	struct memcache *dptr_cache;
 };
 
 static struct smb_Dir *OpenDir_fsp(TALLOC_CTX *mem_ctx, connection_struct *conn,
@@ -82,6 +74,8 @@ static struct smb_Dir *OpenDir_fsp(TALLOC_CTX *mem_ctx, connection_struct *conn,
 			const char *mask,
 			uint32 attr);
 
+static void DirCacheAdd(struct smb_Dir *dirp, const char *name, long offset);
+
 #define INVALID_DPTR_KEY (-3)
 
 /****************************************************************************
@@ -159,8 +153,6 @@ static void dptr_idle(struct dptr_struct *dptr)
 	if (dptr->dir_hnd) {
 		DEBUG(4,("Idling dptr dnum %d\n",dptr->dnum));
 		TALLOC_FREE(dptr->dir_hnd);
-		TALLOC_FREE(dptr->dptr_cache);
-		dptr->counter = 0;
 	}
 }
 
@@ -434,9 +426,8 @@ static struct smb_Dir *open_dir_with_privilege(connection_struct *conn,
 					const char *wcard,
 					uint32_t attr)
 {
-	NTSTATUS status;
 	struct smb_Dir *dir_hnd = NULL;
-	struct smb_filename *smb_fname_cwd = NULL;
+	struct smb_filename *smb_fname_cwd;
 	char *saved_dir = vfs_GetWd(talloc_tos(), conn);
 	struct privilege_paths *priv_paths = req->priv_paths;
 	int ret;
@@ -450,11 +441,9 @@ static struct smb_Dir *open_dir_with_privilege(connection_struct *conn,
 	}
 
 	/* Now check the stat value is the same. */
-	status = create_synthetic_smb_fname(talloc_tos(), ".",
-					NULL, NULL,
-					&smb_fname_cwd);
+	smb_fname_cwd = synthetic_smb_fname(talloc_tos(), ".", NULL, NULL);
 
-	if (!NT_STATUS_IS_OK(status)) {
+	if (smb_fname_cwd == NULL) {
 		goto out;
 	}
 	ret = SMB_VFS_STAT(conn, smb_fname_cwd);
@@ -522,14 +511,14 @@ NTSTATUS dptr_create(connection_struct *conn,
 		dir_hnd = OpenDir_fsp(NULL, conn, fsp, wcard, attr);
 	} else {
 		int ret;
-		struct smb_filename *smb_dname = NULL;
-		NTSTATUS status = create_synthetic_smb_fname(talloc_tos(),
-						path,
-						NULL,
-						NULL,
-						&smb_dname);
-		if (!NT_STATUS_IS_OK(status)) {
-			return status;
+		bool backup_intent = (req && req->priv_paths);
+		struct smb_filename *smb_dname;
+		NTSTATUS status;
+
+		smb_dname = synthetic_smb_fname(talloc_tos(), path,
+						NULL, NULL);
+		if (smb_dname == NULL) {
+			return NT_STATUS_NO_MEMORY;
 		}
 		if (lp_posix_pathnames()) {
 			ret = SMB_VFS_LSTAT(conn, smb_dname);
@@ -544,11 +533,12 @@ NTSTATUS dptr_create(connection_struct *conn,
 		}
 		status = smbd_check_access_rights(conn,
 						smb_dname,
+						backup_intent,
 						SEC_DIR_LIST);
 		if (!NT_STATUS_IS_OK(status)) {
 			return status;
 		}
-		if (req && req->priv_paths) {
+		if (backup_intent) {
 			dir_hnd = open_dir_with_privilege(conn,
 						req,
 						path,
@@ -896,15 +886,6 @@ bool dptr_SearchDir(struct dptr_struct *dptr, const char *name, long *poffset, S
 	return SearchDir(dptr->dir_hnd, name, poffset);
 }
 
-/****************************************************************************
- Add the name we're returning into the underlying cache.
-****************************************************************************/
-
-void dptr_DirCacheAdd(struct dptr_struct *dptr, const char *name, long offset)
-{
-	DirCacheAdd(dptr->dir_hnd, name, offset);
-}
-
 /****************************************************************************
  Initialize variables & state data at the beginning of all search SMB requests.
 ****************************************************************************/
@@ -913,76 +894,6 @@ void dptr_init_search_op(struct dptr_struct *dptr)
 	SMB_VFS_INIT_SEARCH_OP(dptr->conn, dptr->dir_hnd->dir);
 }
 
-/****************************************************************************
- Map a native directory offset to a 32-bit cookie.
-****************************************************************************/
-
-static uint32_t map_dir_offset_to_wire(struct dptr_struct *dptr, long offset)
-{
-	DATA_BLOB key;
-	DATA_BLOB val;
-
-	if (offset == END_OF_DIRECTORY_OFFSET) {
-		return WIRE_END_OF_DIRECTORY_OFFSET;
-	} else if(offset == START_OF_DIRECTORY_OFFSET) {
-		return WIRE_START_OF_DIRECTORY_OFFSET;
-	} else if (offset == DOT_DOT_DIRECTORY_OFFSET) {
-		return WIRE_DOT_DOT_DIRECTORY_OFFSET;
-	}
-	if (sizeof(long) == 4) {
-		/* 32-bit machine. We can cheat... */
-		return (uint32_t)offset;
-	}
-	if (dptr->dptr_cache == NULL) {
-		/* Lazy initialize cache. */
-		dptr->dptr_cache = memcache_init(dptr, 0);
-		if (dptr->dptr_cache == NULL) {
-			return WIRE_END_OF_DIRECTORY_OFFSET;
-		}
-	} else {
-		/* Have we seen this offset before ? */
-		key.data = (void *)&offset;
-		key.length = sizeof(offset);
-		if (memcache_lookup(dptr->dptr_cache,
-					SMB1_SEARCH_OFFSET_MAP,
-					key,
-					&val)) {
-			uint32_t wire_offset;
-			SMB_ASSERT(val.length == sizeof(wire_offset));
-			memcpy(&wire_offset, val.data, sizeof(wire_offset));
-			DEBUG(10,("found wire %u <-> offset %ld\n",
-				(unsigned int)wire_offset,
-				(long)offset));
-			return wire_offset;
-		}
-	}
-	/* Allocate a new wire cookie. */
-	do {
-		dptr->counter++;
-	} while (dptr->counter == WIRE_START_OF_DIRECTORY_OFFSET ||
-		 dptr->counter == WIRE_END_OF_DIRECTORY_OFFSET ||
-		 dptr->counter == WIRE_DOT_DOT_DIRECTORY_OFFSET);
-	/* Store it in the cache. */
-	key.data = (void *)&offset;
-	key.length = sizeof(offset);
-	val.data = (void *)&dptr->counter;
-	val.length = sizeof(dptr->counter); /* MUST BE uint32_t ! */
-	memcache_add(dptr->dptr_cache,
-			SMB1_SEARCH_OFFSET_MAP,
-			key,
-			val);
-	/* And the reverse mapping for lookup from
-	   map_wire_to_dir_offset(). */
-	memcache_add(dptr->dptr_cache,
-			SMB1_SEARCH_OFFSET_MAP,
-			val,
-			key);
-	DEBUG(10,("stored wire %u <-> offset %ld\n",
-		(unsigned int)dptr->counter,
-		(long)offset));
-	return dptr->counter;
-}
-
 /****************************************************************************
  Fill the 5 byte server reserved dptr field.
 ****************************************************************************/
@@ -992,61 +903,19 @@ bool dptr_fill(struct smbd_server_connection *sconn,
 {
 	unsigned char *buf = (unsigned char *)buf1;
 	struct dptr_struct *dptr = dptr_get(sconn, key, false);
-	uint32_t wire_offset;
+	uint32 offset;
 	if (!dptr) {
 		DEBUG(1,("filling null dirptr %d\n",key));
 		return(False);
 	}
-	wire_offset = map_dir_offset_to_wire(dptr,TellDir(dptr->dir_hnd));
+	offset = (uint32)TellDir(dptr->dir_hnd);
 	DEBUG(6,("fill on key %u dirptr 0x%lx now at %d\n",key,
-		(long)dptr->dir_hnd,(int)wire_offset));
+		(long)dptr->dir_hnd,(int)offset));
 	buf[0] = key;
-	SIVAL(buf,1,wire_offset);
+	SIVAL(buf,1,offset);
 	return(True);
 }
 
-/****************************************************************************
- Map a 32-bit wire cookie to a native directory offset.
-****************************************************************************/
-
-static long map_wire_to_dir_offset(struct dptr_struct *dptr, uint32_t wire_offset)
-{
-	DATA_BLOB key;
-	DATA_BLOB val;
-
-	if (wire_offset == WIRE_END_OF_DIRECTORY_OFFSET) {
-		return END_OF_DIRECTORY_OFFSET;
-	} else if(wire_offset == WIRE_START_OF_DIRECTORY_OFFSET) {
-		return START_OF_DIRECTORY_OFFSET;
-	} else if (wire_offset == WIRE_DOT_DOT_DIRECTORY_OFFSET) {
-		return DOT_DOT_DIRECTORY_OFFSET;
-	}
-	if (sizeof(long) == 4) {
-		/* 32-bit machine. We can cheat... */
-		return (long)wire_offset;
-	}
-	if (dptr->dptr_cache == NULL) {
-		/* Logic error, cache should be initialized. */
-		return END_OF_DIRECTORY_OFFSET;
-	}
-	key.data = (void *)&wire_offset;
-	key.length = sizeof(wire_offset);
-	if (memcache_lookup(dptr->dptr_cache,
-				SMB1_SEARCH_OFFSET_MAP,
-				key,
-				&val)) {
-		/* Found mapping. */
-		long offset;
-		SMB_ASSERT(val.length == sizeof(offset));
-		memcpy(&offset, val.data, sizeof(offset));
-		DEBUG(10,("lookup wire %u <-> offset %ld\n",
-			(unsigned int)wire_offset,
-			(long)offset));
-		return offset;
-	}
-	return END_OF_DIRECTORY_OFFSET;
-}
-
 /****************************************************************************
  Fetch the dir ptr and seek it given the 5 byte server field.
 ****************************************************************************/
@@ -1056,7 +925,7 @@ struct dptr_struct *dptr_fetch(struct smbd_server_connection *sconn,
 {
 	unsigned int key = *(unsigned char *)buf;
 	struct dptr_struct *dptr = dptr_get(sconn, key, false);
-	uint32_t wire_offset;
+	uint32 offset;
 	long seekoff;
 
 	if (!dptr) {
@@ -1064,8 +933,12 @@ struct dptr_struct *dptr_fetch(struct smbd_server_connection *sconn,
 		return(NULL);
 	}
 	*num = key;
-	wire_offset = IVAL(buf,1);
-	seekoff = map_wire_to_dir_offset(dptr, wire_offset);
+	offset = IVAL(buf,1);
+	if (offset == (uint32)-1) {
+		seekoff = END_OF_DIRECTORY_OFFSET;
+	} else {
+		seekoff = (long)offset;
+	}
 	SeekDir(dptr->dir_hnd,seekoff);
 	DEBUG(3,("fetching dirptr %d for path %s at offset %d\n",
 		key, dptr->path, (int)seekoff));
@@ -1169,7 +1042,6 @@ bool smbd_dirptr_get_entry(TALLOC_CTX *ctx,
 		struct smb_filename smb_fname;
 		uint32_t mode = 0;
 		bool ok;
-		NTSTATUS status;
 
 		cur_offset = dptr_TellDir(dirptr);
 		prev_offset = cur_offset;
@@ -1265,9 +1137,9 @@ bool smbd_dirptr_get_entry(TALLOC_CTX *ctx,
 
 		TALLOC_FREE(dname);
 
-		status = copy_smb_filename(ctx, &smb_fname, _smb_fname);
+		*_smb_fname = cp_smb_filename(ctx, &smb_fname);
 		TALLOC_FREE(pathreal);
-		if (!NT_STATUS_IS_OK(status)) {
+		if (*_smb_fname == NULL) {
 			return false;
 		}
 		*_fname = fname;
@@ -1406,6 +1278,7 @@ static bool user_can_read_file(connection_struct *conn,
 
 	return NT_STATUS_IS_OK(smbd_check_access_rights(conn,
 				smb_fname,
+				false,
 				FILE_READ_DATA));
 }
 
@@ -1480,7 +1353,6 @@ bool is_visible_file(connection_struct *conn, const char *dir_path,
 	bool hide_special = lp_hide_special_files(SNUM(conn));
 	char *entry = NULL;
 	struct smb_filename *smb_fname_base = NULL;
-	NTSTATUS status;
 	bool ret = false;
 
 	if ((strcmp(".",name) == 0) || (strcmp("..",name) == 0)) {
@@ -1501,9 +1373,9 @@ bool is_visible_file(connection_struct *conn, const char *dir_path,
 		}
 
 		/* Create an smb_filename with stream_name == NULL. */
-		status = create_synthetic_smb_fname(talloc_tos(), entry, NULL,
-						    pst, &smb_fname_base);
-		if (!NT_STATUS_IS_OK(status)) {
+		smb_fname_base = synthetic_smb_fname(talloc_tos(), entry, NULL,
+						     pst);
+		if (smb_fname_base == NULL) {
 			ret = false;
 			goto out;
 		}
@@ -1796,7 +1668,7 @@ long TellDir(struct smb_Dir *dirp)
  Add an entry into the dcache.
 ********************************************************************/
 
-void DirCacheAdd(struct smb_Dir *dirp, const char *name, long offset)
+static void DirCacheAdd(struct smb_Dir *dirp, const char *name, long offset)
 {
 	struct name_cache_entry *e;
 
